@@ -437,6 +437,10 @@ class AlertDialog extends React.Component {
           value: METHOD_TYPE_SNMP,
           label: _('SNMP'),
         },
+        {
+          value: METHOD_TYPE_START_TASK,
+          label: _('Start Task'),
+        },
         {
           value: METHOD_TYPE_SYSLOG,
           label: _('System Logger'),
@@ -581,7 +585,7 @@ class AlertDialog extends React.Component {
                     />
                   )}
 
-                  {secinfoEvent && (
+                  {(secinfoEvent || taskEvent) && (
                     <FilterCountLeastConditionPart
                       prefix="condition_data"
                       condition={values.condition}
